package Sah::Schemas::Perl;

our $DATE = '2020-05-08'; # DATE
our $VERSION = '0.030'; # VERSION

1;
# ABSTRACT: Sah schemas related to Perl

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::Schemas::Perl - Sah schemas related to Perl

=head1 VERSION

This document describes version 0.030 of Sah::Schemas::Perl (from Perl distribution Sah-Schemas-Perl), released on 2020-05-08.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Perl>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Perl>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Perl>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Sah> - specification

L<Data::Sah>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020, 2019, 2018, 2017, 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
